@@ -1,9 +1,6 @@
 import ssl
 
 from celery import Celery
-from kombu.serialization import register
-from qcelemental.util.serialization import json_dumps as qcel_json_dumps
-from qcelemental.util.serialization import json_loads as qcel_json_loads
 
 from .config import settings
 
@@ -15,23 +12,12 @@ bigchem = Celery(
     backend=settings.bigchem_backend_url,
 )
 
-# To serialize more complex data structures from QCElemental as json (like AtomicResult
-# objs)
-register(
-    "qceljson",
-    qcel_json_dumps,
-    qcel_json_loads,
-    content_type="application/x-qceljson",
-    content_encoding="utf-8",
-)
-
 bigchem.conf.update(
     # All configuration documentation here:
     # https://docs.celeryq.dev/en/stable/userguide/configuration.html
-    # task_serializer="qceljson",
-    # accept_content=["qceljson"],
-    # result_serializer="qceljson",
-    # NOTE: Switched to pickle serializer for now so that chords receive python objects
+    # NOTE: Using pickle serializer so that chords receive python objects.
+    # Can use JSON serializer json_dumps from qcio.utils if JSON is preferred.
+    broker_connection_retry_on_startup=True,
     task_serializer="pickle",
     accept_content=["pickle"],
     result_serializer="pickle",
